<?php
/*
Plugin Name: Convious
Description: Inserts Convious script onto your website.
Version: 1.0.0
Author: Codeopera
Author URI: https://www.codeopera.com/
Text Domain: convious
Domain Path: /languages
*/

if ( ! class_exists( 'Codeopera_Convious' ) ) {
    class Codeopera_Convious {
        private static $instance;
        public $plugin_url = '';
        public $plugin_path = '';

        public static function get_instance() {
            if ( ! self::$instance ) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        public function __construct() {
            $this->version = '1.0.0';
            $this->script_url = 'https://client.convious-app.com/loader.js?k=';
            $this->plugin_url = plugins_url( '/', __FILE__ );
            $this->plugin_path = plugin_dir_path( __FILE__ );
            $this->plugin_name = 'Convious';
            $this->plugin_class = 'Codeopera_Convious';
            $this->plugin_options_name = 'codeopera_convious';
            $this->plugin_options = array();
            $this->menu_slug = 'convious';
            $this->load_language( 'convious' );
            if ( self::$instance ) {
                wp_die( sprintf( '<strong>%s:</strong> Please use the <code>%s::instance()</code> method for initialization.', $this->plugin_class, __CLASS__ ) );
            }
            add_action( 'admin_menu', array( $this, 'add_admin_menu' ) );
            add_action( 'admin_init', array( $this, 'settings_init' ) );
            add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ) , array( $this, 'add_settings_link' ) );
            add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
            add_filter( 'script_loader_tag', array( $this, 'script_add_async' ), 10, 3 );
        }

        public function load_language( $domain ) {
            load_plugin_textdomain( $domain, false, $this->plugin_path . 'languages' );
        }

        public function add_settings_link( $links ) {
            $settings_link = '<a href="options-general.php?page=' . $this->menu_slug . '">' . __( 'Settings', 'convious' ) . '</a>';
            array_push( $links, $settings_link );
            return $links;
        }
        
        public function add_admin_menu() {
            add_options_page( $this->plugin_name, $this->plugin_name, 'manage_options', $this->menu_slug, array( $this, 'add_admin_menu_callback' ) );
        }

        public function add_admin_menu_callback() {
            if ( ! current_user_can( 'manage_options' ) ) {
                wp_die( __( 'You do not have sufficient permissions to access this page.', 'convious' ) );
            }
            if ( isset( $_POST['action'] ) && ! wp_verify_nonce( $_POST['nonce'], $this->plugin_class ) ) {
                wp_die( __( 'Security check failed! Settings not saved.', 'convious' ) );
            }
            ?>
            <div class="wrap">
                <h1><?php echo $this->plugin_name; ?> <?php _e( 'Settings', 'convious' ); ?></h1>
                <form method="post" action="options.php">
                    <?php settings_fields( $this->plugin_options_name ); ?>
                    <?php do_settings_sections( $this->plugin_options_name ); ?>
                    <?php submit_button(); ?>
                </form>
            </div>
            <?php
        }

        public function settings_init() {
            $this->plugin_options = get_option( $this->plugin_options_name );
            register_setting( $this->plugin_options_name, $this->plugin_options_name );
            add_settings_section( 'general', null, null, $this->plugin_options_name );
            add_settings_field(
                $this->plugin_options_name,
                'Convious Identifier',
                array( $this, 'field_render_input_text' ),
                $this->plugin_options_name,
                'general',
                array(
                    'name' => 'client_id',
                )
            );
        }

        public function field_render_input_text( $args ) {
            extract( $args );
            $options = $this->plugin_options;
            $value = ( ! empty( $options ) ) ? esc_attr( $options[$name] ) : '';
            ?>
            <input type="text" class="regular-text" name="<?php echo $this->plugin_options_name; ?>[<?php echo $name; ?>]" value="<?php echo $value; ?>" />
            <?php
        }

        public function enqueue_scripts() {
            $options = get_option( $this->plugin_options_name );
            $client_id = ( ! empty( $options ) && ! empty( $options['client_id'] ) ) ? $options['client_id'] : false;
            if ( $client_id ) {
                wp_enqueue_script( 'codeopera-convious', $this->script_url . $client_id, array(), null, false );
            }
        }

        function script_add_async( $tag, $handle, $src ) {
            if ( $handle !== 'codeopera-convious' ) {
                return $tag;
            }
            return '<script id="convious_loader" src="' . $src . '" async=""></script>' . PHP_EOL;
        }
    }
    Codeopera_Convious::get_instance();
}